@@ -40,7 +40,7 @@ export class IdlClassTemplateDirective {
     selector: 'eg-combobox',
     templateUrl: './combobox.component.html',
     styles: [`
-    .icons {margin-left:-18px}
+    .icons {margin-inline-start:-18px}
     .material-icons {font-size: 16px;font-weight:bold}
   `],
     providers: [{
@@ -96,7 +96,8 @@ implements ControlValueAccessor, OnInit, AfterViewInit, OnChanges {
     @Input() startsWith = false;
 
     @Input() clearOnAsync = false;
-    @Input() isEditable = false;
+    // Master ON switch for ngbTypeahead; always true. Use allowFreeText to enable free text entry.
+    isEditable = true;
     @Input() selectOnExact = false;
 
     // Add a 'required' attribute to the input
