@@ -205,9 +205,9 @@ implements OnInit, AfterViewInit, OnDestroy {
 
             case 'ffld': {
                 this.applyFFOptions();
-                // these fixed fields can include multiple values (which doesn't work well with combobox) or free text
+                // these fixed fields contain free text
                 // TODO: remove check for AUT when authorities fixed field data is populated
-                const complexFields = ['AccM','Cont','Date1','Date2','Ills','LTxt','Relf','SpFm','Time'];
+                const complexFields = ['Date1','Date2','Time'];
                 if (complexFields.includes(this.fixedFieldCode) || this.record.recordType() === 'AUT' ) {
                     this.suggest = false;
                 }
